.. currentmodule:: disnake_compass

Fields Implementation
=====================

.. automodule:: disnake_compass.fields


Enums
-----

.. autoenum:: FieldMetadata
    :members:


.. autoflag:: FieldType
    :members:


Functions
---------

.. autofunction:: field

.. autofunction:: get_field_type

.. autofunction:: get_fields

.. autofunction:: get_parser

.. autofunction:: internal

.. autofunction:: is_field_of_type
